@@ -105,14 +105,16 @@ getXdgConfigFile = xmobarConfigDir >>= return . (</> "xmobarrc")
 -- | Read default configuration file or load the default config
 readDefaultConfig :: IO (Config,[String])
 readDefaultConfig = do
-  xdgconf <- getXdgConfigFile
-  x <- io $ fileExist xdgconf
+  xdgConfigFile <- getXdgConfigFile
+  xdgConfigFileExists <- io $ fileExist xdgConfigFile
   home <- io $ getEnv "HOME"
-  let path = home ++ "/.xmobarrc"
-  f <- io $ fileExist path
-  if x then readConfig path
-       else if f then readConfig path
-                 else return (defaultConfig,[])
+  let defaultConfigFile = home ++ "/.xmobarrc"
+  defaultConfigFileExists <- io $ fileExist defaultConfigFile
+  if xdgConfigFileExists
+    then readConfig xdgConfigFile
+    else if defaultConfigFileExists
+         then readConfig defaultConfigFile
+         else return (defaultConfig,[])
 
 data Opts = Help
           | Version
@@ -173,7 +175,7 @@ usage = usageInfo header options ++ footer
 info :: String
 info = "xmobar " ++ showVersion version
         ++ "\n (C) 2007 - 2010 Andrea Rossato "
-        ++ "\n (C) 2010 - 2013 Jose A Ortega Ruiz\n "
+        ++ "\n (C) 2010 - 2014 Jose A Ortega Ruiz\n "
         ++ mail ++ "\n" ++ license
 
 mail :: String
@@ -186,7 +188,7 @@ license = "\nThis program is distributed in the hope that it will be useful," ++
           "\nSee the License for more details."
 
 doOpts :: Config -> [Opts] -> IO Config
-doOpts conf [] = 
+doOpts conf [] =
   return (conf {lowerOnStart = lowerOnStart conf && overrideRedirect conf})
 doOpts conf (o:oo) =
   case o of
@@ -215,4 +217,3 @@ doOpts conf (o:oo) =
                         "specified with the -" ++ c:" option\n")
         readStr str = [x | (x,t) <- reads str, ("","") <- lex t]
         doOpts' opts = doOpts opts oo
-
