@@ -38,7 +38,8 @@ runCoreTemp _ = do
    dn <- getConfigValue decDigits
    failureMessage <- getConfigValue naString
    let path = ["/sys/bus/platform/devices/coretemp.", "/temp", "_input"]
+       path' = ["/sys/bus/platform/devices/coretemp.", "/hwmon/hwmon", "/temp", "_input"]
        lbl  = Just ("_label", read . (dropWhile (not . isDigit)))
        divisor = 1e3 :: Double
        show' = showDigits (max 0 dn)
-   checkedDataRetrieval failureMessage path lbl (/divisor) show'
+   checkedDataRetrieval failureMessage [path, path'] lbl (/divisor) show'
