@@ -22,14 +22,14 @@ import Data.IORef (IORef, newIORef, readIORef, writeIORef)
 cpuConfig :: IO MConfig
 cpuConfig = mkMConfig
        "Cpu: <total>%"
-       ["bar","total","user","nice","system","idle","iowait"]
+       ["bar","vbar","total","user","nice","system","idle","iowait"]
 
-type CpuDataRef = IORef [Float]
+type CpuDataRef = IORef [Int]
 
-cpuData :: IO [Float]
+cpuData :: IO [Int]
 cpuData = cpuParser `fmap` B.readFile "/proc/stat"
 
-cpuParser :: B.ByteString -> [Float]
+cpuParser :: B.ByteString -> [Int]
 cpuParser = map (read . B.unpack) . tail . B.words . head . B.lines
 
 parseCpu :: CpuDataRef -> IO [Float]
@@ -38,17 +38,18 @@ parseCpu cref =
        b <- cpuData
        writeIORef cref b
        let dif = zipWith (-) b a
-           tot = foldr (+) 0 dif
-           percent = map (/ tot) dif
+           tot = fromIntegral $ foldr (+) 0 dif
+           percent = map (/ tot) (map fromIntegral dif)
        return percent
 
 formatCpu :: [Float] -> Monitor [String]
-formatCpu [] = return $ replicate 6 ""
+formatCpu [] = return $ replicate 8 ""
 formatCpu xs = do
   let t = sum $ take 3 xs
   b <- showPercentBar (100 * t) t
+  v <- showVerticalBar (100 * t) t
   ps <- showPercentsWithColors (t:xs)
-  return (b:ps)
+  return (b:v:ps)
 
 runCpu :: CpuDataRef -> [String] -> Monitor String
 runCpu cref _ =
