@@ -23,15 +23,18 @@ import Control.Exception (SomeException, handle)
 import Control.Monad (zipWithM)
 import qualified Data.ByteString.Lazy.Char8 as B
 import Data.List (isPrefixOf, find)
-import System.Directory (canonicalizePath)
+import Data.Maybe (catMaybes)
+import System.Directory (canonicalizePath, doesFileExist)
 
 diskIOConfig :: IO MConfig
-diskIOConfig = mkMConfig "" ["total", "read", "write",
-                             "totalbar", "readbar", "writebar"]
+diskIOConfig = mkMConfig "" ["total", "read", "write"
+                            ,"totalbar", "readbar", "writebar"
+                            ,"totalvbar", "readvbar", "writevbar"
+                            ]
 
 diskUConfig :: IO MConfig
 diskUConfig = mkMConfig ""
-              ["size", "free", "used", "freep", "usedp", "freebar", "usedbar"]
+              ["size", "free", "used", "freep", "usedp", "freebar", "freevbar", "usedbar", "usedvbar"]
 
 type DevName = String
 type Path = String
@@ -40,11 +43,15 @@ type DevDataRef = IORef [(DevName, [Float])]
 mountedDevices :: [String] -> IO [(DevName, Path)]
 mountedDevices req = do
   s <- B.readFile "/etc/mtab"
-  parse `fmap` mapM canon (devs s)
+  parse `fmap` mapM mbcanon (devs s)
   where
+    mbcanon (d, p) = doesFileExist d >>= \e ->
+                     if e
+                        then Just `fmap` canon (d,p)
+                        else return Nothing
     canon (d, p) = do {d' <- canonicalizePath d; return (d', p)}
     devs = filter isDev . map (firstTwo . B.words) . B.lines
-    parse = map undev . filter isReq
+    parse = map undev . filter isReq . catMaybes
     firstTwo (a:b:_) = (B.unpack a, B.unpack b)
     firstTwo _ = ("", "")
     isDev (d, _) = "/dev/" `isPrefixOf` d
@@ -124,8 +131,9 @@ runDiskIO' :: (String, [Float]) -> Monitor String
 runDiskIO' (tmp, xs) = do
   s <- mapM (showWithColors speedToStr) xs
   b <- mapM (showLogBar 0.8) xs
+  vb <- mapM (showLogVBar 0.8) xs
   setConfigValue tmp template
-  parseTemplate $ s ++ b
+  parseTemplate $ s ++ b ++ vb
 
 runDiskIO :: DevDataRef -> [(String, String)] -> [String] -> Monitor String
 runDiskIO dref disks _ = do
@@ -162,8 +170,10 @@ runDiskU' tmp path = do
   s <- zipWithM showWithColors' strs [100, freep, 100 - freep]
   sp <- showPercentsWithColors [fr, 1 - fr]
   fb <- showPercentBar (fromIntegral freep) fr
+  fvb <- showVerticalBar (fromIntegral freep) fr
   ub <- showPercentBar (fromIntegral $ 100 - freep) (1 - fr)
-  parseTemplate $ s ++ sp ++ [fb, ub]
+  uvb <- showVerticalBar (fromIntegral $ 100 - freep) (1 - fr)
+  parseTemplate $ s ++ sp ++ [fb,fvb,ub,uvb]
   where ign = const (return [0, 0, 0]) :: SomeException -> IO [Integer]
 
 
