@@ -15,11 +15,12 @@
 module Plugins.Monitors.Mem (memConfig, runMem, totalMem, usedMem) where
 
 import Plugins.Monitors.Common
+import qualified Data.Map as M
 
 memConfig :: IO MConfig
 memConfig = mkMConfig
        "Mem: <usedratio>% (<cache>M)" -- template
-       ["usedbar", "freebar", "usedratio", "freeratio", "total",
+       ["usedbar", "usedvbar", "freebar", "freevbar", "usedratio", "freeratio", "total",
         "free", "buffer", "cache", "rest", "used"] -- available replacements
 
 fileMEM :: IO String
@@ -28,10 +29,11 @@ fileMEM = readFile "/proc/meminfo"
 parseMEM :: IO [Float]
 parseMEM =
     do file <- fileMEM
-       let content = map words $ take 4 $ lines file
-           [total, free, buffer, cache] = map (\line -> (read $ line !! 1 :: Float) / 1024) content
+       let content = map words $ take 8 $ lines file
+           info = M.fromList $ map (\line -> (line !! 0, (read $ line !! 1 :: Float) / 1024)) content
+           [total, free, buffer, cache] = map (info M.!) ["MemTotal:", "MemFree:", "Buffers:", "Cached:"]
            rest = free + buffer + cache
-           used = total - rest
+           used = total - (M.findWithDefault rest "MemAvailable:" info)
            usedratio = used / total
            freeratio = free / total
        return [usedratio, freeratio, total, free, buffer, cache, rest, used, freeratio]
@@ -47,11 +49,13 @@ formatMem (r:fr:xs) =
     do let f = showDigits 0
            rr = 100 * r
        ub <- showPercentBar rr r
+       uvb <- showVerticalBar rr r
        fb <- showPercentBar (100 - rr) (1 - r)
+       fvb <- showVerticalBar (100 - rr) ( 1 - r)
        rs <- showPercentWithColors r
        fs <- showPercentWithColors fr
        s <- mapM (showWithColors f) xs
-       return (ub:fb:rs:fs:s)
+       return (ub:uvb:fb:fvb:rs:fs:s)
 formatMem _ = replicate 10 `fmap` getConfigValue naString
 
 runMem :: [String] -> Monitor String
