@@ -1,7 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Plugins.Monitors.Net
--- Copyright   :  (c) 2011, 2012, 2013 Jose Antonio Ortega Ruiz
+-- Copyright   :  (c) 2011, 2012, 2013, 2014 Jose Antonio Ortega Ruiz
 --                (c) 2007-2010 Andrea Rossato
 -- License     :  BSD-style (see LICENSE)
 --
@@ -53,7 +53,7 @@ instance Ord NetDev where
 netConfig :: IO MConfig
 netConfig = mkMConfig
     "<dev>: <rx>KB|<tx>KB"      -- template
-    ["dev", "rx", "tx", "rxbar", "txbar"]     -- available replacements
+    ["dev", "rx", "tx", "rxbar", "rxvbar", "txbar", "txvbar"]     -- available replacements
 
 operstateDir :: String -> FilePath
 operstateDir d = "/sys/class/net" </> d </> "operstate"
@@ -67,7 +67,7 @@ existingDevs = getDirectoryContents "/sys/class/net" >>= filterM isDev
 isUp :: String -> IO Bool
 isUp d = do
   operstate <- B.readFile (operstateDir d)
-  return $ "up" == (B.unpack . head . B.lines) operstate
+  return $ (B.unpack . head . B.lines) operstate `elem`  ["up", "unknown"]
 
 readNetDev :: [String] -> IO NetDev
 readNetDev (d:x:y:_) = do
@@ -97,22 +97,23 @@ findNetDev dev = do
         isDev (NI d) = d == dev
         isDev NA = False
 
-formatNet :: Float -> Monitor (String, String)
+formatNet :: Float -> Monitor (String, String, String)
 formatNet d = do
     s <- getConfigValue useSuffix
     dd <- getConfigValue decDigits
     let str = if s then (++"Kb/s") . showDigits dd else showDigits dd
     b <- showLogBar 0.9 d
+    vb <- showLogVBar 0.9 d
     x <- showWithColors str d
-    return (x, b)
+    return (x, b, vb)
 
 printNet :: NetDev -> Monitor String
 printNet nd =
   case nd of
     ND d r t -> do
-        (rx, rb) <- formatNet r
-        (tx, tb) <- formatNet t
-        parseTemplate [d,rx,tx,rb,tb]
+        (rx, rb, rvb) <- formatNet r
+        (tx, tb, tvb) <- formatNet t
+        parseTemplate [d,rx,tx,rb,rvb,tb,tvb]
     NI _ -> return ""
     NA -> getConfigValue naString
 
