@@ -24,7 +24,7 @@ import System.Console.GetOpt
 
 volumeConfig :: IO MConfig
 volumeConfig = mkMConfig "Vol: <volume>% <status>"
-                         ["volume", "volumebar", "dB","status"]
+                         ["volume", "volumebar", "volumevbar", "dB","status"]
 
 
 data VolumeOpts = VolumeOpts
@@ -76,6 +76,10 @@ formatVolBar :: Integer -> Integer -> Integer -> Monitor String
 formatVolBar lo hi v =
     showPercentBar (100 * x) x where x = percent v lo hi
 
+formatVolVBar :: Integer -> Integer -> Integer -> Monitor String
+formatVolVBar lo hi v =
+    showVerticalBar (100 * x) x where x = percent v lo hi
+
 switchHelper :: VolumeOpts
              -> (VolumeOpts -> Maybe String)
              -> (VolumeOpts -> String)
@@ -110,16 +114,19 @@ formatDb opts dbi = do
 runVolume :: String -> String -> [String] -> Monitor String
 runVolume mixerName controlName argv = do
     opts <- io $ parseOpts argv
-    control <- io $ getControlByName mixerName controlName
-    (lo, hi) <- io . liftMaybe $ getRange <$> volumeControl control
-    val <- getVal $ volumeControl control
-    db <- getDB $ volumeControl control
-    sw <- getSw $ switchControl control
+    (lo, hi, val, db, sw) <- io $ withMixer mixerName $ \mixer -> do
+        control <- getControlByName mixer controlName
+        (lo, hi) <- liftMaybe $ getRange <$> volumeControl control
+        val <- getVal $ volumeControl control
+        db <- getDB $ volumeControl control
+        sw <- getSw $ switchControl control
+        return (lo, hi, val, db, sw)
     p <- liftMonitor $ liftM3 formatVol lo hi val
     b <- liftMonitor $ liftM3 formatVolBar lo hi val
+    v <- liftMonitor $ liftM3 formatVolVBar lo hi val
     d <- getFormatDB opts db
     s <- getFormatSwitch opts sw
-    parseTemplate [p, b, d, s]
+    parseTemplate [p, b, v, d, s]
 
   where
 
@@ -138,18 +145,18 @@ runVolume mixerName controlName argv = do
     liftMonitor Nothing = unavailable
     liftMonitor (Just m) = m
 
-    getDB :: Maybe Volume -> Monitor (Maybe Integer)
+    getDB :: Maybe Volume -> IO (Maybe Integer)
     getDB Nothing = return Nothing
-    getDB (Just v) = io $ AE.catch (getChannel FrontLeft $ dB v)
-                                   (const $ return $ Just 0)
+    getDB (Just v) = AE.catch (getChannel FrontLeft $ dB v)
+                              (const $ return $ Just 0)
 
-    getVal :: Maybe Volume -> Monitor (Maybe Integer)
+    getVal :: Maybe Volume -> IO (Maybe Integer)
     getVal Nothing = return Nothing
-    getVal (Just v) = io $ getChannel FrontLeft $ value v
+    getVal (Just v) = getChannel FrontLeft $ value v
 
-    getSw :: Maybe Switch -> Monitor (Maybe Bool)
+    getSw :: Maybe Switch -> IO (Maybe Bool)
     getSw Nothing = return Nothing
-    getSw (Just s) = io $ getChannel FrontLeft s
+    getSw (Just s) = getChannel FrontLeft s
 
     getFormatDB :: VolumeOpts -> Maybe Integer -> Monitor String
     getFormatDB _ Nothing = unavailable
